[Rt-commit] r10683 - in rt/branches/3.999-DANGEROUS: . html/Admin/CustomFields html/Admin/Elements html/Admin/Global html/Admin/Groups html/Admin/Queues html/Admin/Users html/Elements html/Elements/GnuPG html/Elements/RT__Model__Ticket html/Search html/Search/Elements html/SelfService html/Ticket html/Ticket/Elements html/User/Groups lib/RT lib/RT/Interface lib/RT/Model lib/RT/ScripAction t/api t/web

jesse at bestpractical.com jesse at bestpractical.com
Sun Feb 3 00:25:28 EST 2008


Author: jesse
Date: Sun Feb  3 00:25:21 2008
New Revision: 10683

Modified:
   rt/branches/3.999-DANGEROUS/   (props changed)
   rt/branches/3.999-DANGEROUS/html/Admin/CustomFields/Modify.html
   rt/branches/3.999-DANGEROUS/html/Admin/Elements/EditCustomField
   rt/branches/3.999-DANGEROUS/html/Admin/Elements/EditScrip
   rt/branches/3.999-DANGEROUS/html/Admin/Global/Template.html
   rt/branches/3.999-DANGEROUS/html/Admin/Groups/Modify.html
   rt/branches/3.999-DANGEROUS/html/Admin/Queues/Modify.html
   rt/branches/3.999-DANGEROUS/html/Admin/Queues/Template.html
   rt/branches/3.999-DANGEROUS/html/Admin/Users/Modify.html
   rt/branches/3.999-DANGEROUS/html/Elements/GnuPG/SelectKeyForEncryption
   rt/branches/3.999-DANGEROUS/html/Elements/GnuPG/SignEncryptWidget
   rt/branches/3.999-DANGEROUS/html/Elements/GnuPGKeyIssues
   rt/branches/3.999-DANGEROUS/html/Elements/RT__Model__Ticket/ColumnMap
   rt/branches/3.999-DANGEROUS/html/Elements/ValidateCustomFields
   rt/branches/3.999-DANGEROUS/html/Search/Bulk.html
   rt/branches/3.999-DANGEROUS/html/Search/Elements/BuildFormatString
   rt/branches/3.999-DANGEROUS/html/SelfService/Display.html
   rt/branches/3.999-DANGEROUS/html/Ticket/Create.html
   rt/branches/3.999-DANGEROUS/html/Ticket/Display.html
   rt/branches/3.999-DANGEROUS/html/Ticket/Elements/PreviewScrips
   rt/branches/3.999-DANGEROUS/html/Ticket/Forward.html
   rt/branches/3.999-DANGEROUS/html/Ticket/GnuPG.html
   rt/branches/3.999-DANGEROUS/html/Ticket/History.html
   rt/branches/3.999-DANGEROUS/html/Ticket/Modify.html
   rt/branches/3.999-DANGEROUS/html/Ticket/ModifyAll.html
   rt/branches/3.999-DANGEROUS/html/Ticket/ModifyDates.html
   rt/branches/3.999-DANGEROUS/html/Ticket/ModifyLinks.html
   rt/branches/3.999-DANGEROUS/html/Ticket/ModifyPeople.html
   rt/branches/3.999-DANGEROUS/html/Ticket/Reminders.html
   rt/branches/3.999-DANGEROUS/html/Ticket/Update.html
   rt/branches/3.999-DANGEROUS/html/User/Groups/Modify.html
   rt/branches/3.999-DANGEROUS/html/User/Prefs.html
   rt/branches/3.999-DANGEROUS/lib/RT/Interface/Web.pm
   rt/branches/3.999-DANGEROUS/lib/RT/Model/Transaction.pm
   rt/branches/3.999-DANGEROUS/lib/RT/Model/User.pm
   rt/branches/3.999-DANGEROUS/lib/RT/Record.pm
   rt/branches/3.999-DANGEROUS/lib/RT/ScripAction/CreateTickets.pm
   rt/branches/3.999-DANGEROUS/t/api/cf_transaction.t
   rt/branches/3.999-DANGEROUS/t/web/gnupg-outgoing.t
   rt/branches/3.999-DANGEROUS/t/web/gnupg-select-keys-on-create.t
   rt/branches/3.999-DANGEROUS/t/web/gnupg-select-keys-on-update.t

Log:
 r76122 at pinglin:  jesse | 2008-02-03 00:18:28 -0500
 more gnupg fixes. not there yet
 r76123 at pinglin:  jesse | 2008-02-03 00:21:07 -0500
 * Fingerprint -> fingerprint fixes


Modified: rt/branches/3.999-DANGEROUS/html/Admin/CustomFields/Modify.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Admin/CustomFields/Modify.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Admin/CustomFields/Modify.html	Sun Feb  3 00:25:21 2008
@@ -167,9 +167,9 @@
 
     my @attribs = qw(disabled pattern name type_composite lookup_type description link_value_to include_content_for_value);
     push @results, update_record_object(
-        AttributesRef => \@attribs,
+        attributes_ref => \@attribs,
         object        => $CustomFieldObj,
-        ARGSRef       => \%ARGS
+        args_ref       => \%ARGS
     );
     $CustomFieldObj->set_values_class( $valuesClass );
 

Modified: rt/branches/3.999-DANGEROUS/html/Admin/Elements/EditCustomField
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Admin/Elements/EditCustomField	(original)
+++ rt/branches/3.999-DANGEROUS/html/Admin/Elements/EditCustomField	Sun Feb  3 00:25:21 2008
@@ -123,7 +123,7 @@
 
       my @aresults = process_custom_field_updates ( 
                         CustomFieldObj => $CustomFieldObj,
-                        ARGSRef => \%ARGS );
+                        args_ref => \%ARGS );
       push @results, @aresults;
     }
 

Modified: rt/branches/3.999-DANGEROUS/html/Admin/Elements/EditScrip
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Admin/Elements/EditScrip	(original)
+++ rt/branches/3.999-DANGEROUS/html/Admin/Elements/EditScrip	Sun Feb  3 00:25:21 2008
@@ -187,10 +187,10 @@
     my @attribs = qw(queue scrip_action scrip_condition template stage
         description custom_prepare_code custom_commit_code custom_is_applicable_code);
     my @results = update_record_object(
-        AttributesRef   => \@attribs,
+        attributes_ref   => \@attribs,
         AttributePrefix => 'Scrip-'.$scrip->id,
         object          => $scrip,
-        ARGSRef         => \%ARGS
+        args_ref         => \%ARGS
     );
     return ($scrip->id, @results);
 }

Modified: rt/branches/3.999-DANGEROUS/html/Admin/Global/Template.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Admin/Global/Template.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Admin/Global/Template.html	Sun Feb  3 00:25:21 2008
@@ -107,9 +107,9 @@
 }
 if ($template_obj->id()) {
   my @attribs = qw( description content queue name);
-  my @aresults = update_record_object( AttributesRef => \@attribs, 
+  my @aresults = update_record_object( attributes_ref => \@attribs, 
 				     object => $template_obj, 
-				     ARGSRef => \%ARGS);
+				     args_ref => \%ARGS);
   $current_subtab = "Admin/Global/Template.html?queue=0&Template=".$template_obj->id();
   $subtabs->{"C"} = { title => _('Template #%1', $template_obj->id()),
   		     	path => "Admin/Global/Template.html?queue=0&Template=".$template_obj->id(),

Modified: rt/branches/3.999-DANGEROUS/html/Admin/Groups/Modify.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Admin/Groups/Modify.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Admin/Groups/Modify.html	Sun Feb  3 00:25:21 2008
@@ -137,11 +137,11 @@
 if ($id) {
     
     my @fields = qw(description name );
-    my @fieldresults = update_record_object ( AttributesRef => \@fields,
+    my @fieldresults = update_record_object ( attributes_ref => \@fields,
 					    object => $Group,
-					    ARGSRef => \%ARGS );
+					    args_ref => \%ARGS );
     push (@results, at fieldresults);
-    push @results, process_object_custom_field_updates( ARGSRef => \%ARGS, object => $Group );
+    push @results, process_object_custom_field_updates( args_ref => \%ARGS, object => $Group );
 }
 
 #we're asking about enabled on the web page but really care about disabled.

Modified: rt/branches/3.999-DANGEROUS/html/Admin/Queues/Modify.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Admin/Queues/Modify.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Admin/Queues/Modify.html	Sun Feb  3 00:25:21 2008
@@ -138,7 +138,6 @@
     $current_tab = 'Admin/Queues/Modify.html?id='.$queue_obj->id;
 }
 if ( $queue_obj->id ) {
-    delete $session{'create_in_queues'};
     my @attribs= qw(description correspond_address comment_address name
         initial_priority final_priority default_due_in sign encrypt disabled);
 
@@ -150,9 +149,9 @@
     }
 
     push @results, update_record_object(
-        AttributesRef => \@attribs,
+        attributes_ref => \@attribs,
         object => $queue_obj, 
-        ARGSRef => \%ARGS
+        args_ref => \%ARGS
     );
 
     $disabled = $ARGS{'disabled'} = $enabled? 0: 1;
@@ -163,7 +162,7 @@
     $m->callback(
         results      => \@linkresults,
         RecordObj    => $queue_obj,
-        ARGSRef      => \%ARGS, 
+        args_ref      => \%ARGS, 
         Callbackname => 'ProcessLinks'
     );
     push @results, @linkresults;

Modified: rt/branches/3.999-DANGEROUS/html/Admin/Queues/Template.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Admin/Queues/Template.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Admin/Queues/Template.html	Sun Feb  3 00:25:21 2008
@@ -108,9 +108,9 @@
   $queue_obj = $template_obj->queue_obj;
 
   my @attribs = qw( description content queue name);
-  my @aresults = update_record_object( AttributesRef => \@attribs, 
+  my @aresults = update_record_object( attributes_ref => \@attribs, 
 				     object => $template_obj, 
-				     ARGSRef => \%ARGS);
+				     args_ref => \%ARGS);
   $current_subtab = "Admin/Queues/Template.html?queue=$queue&Template=".$template_obj->id();
   $subtabs->{"C"} = { title => _('Template #%1', $template_obj->id()),
   		     	path => "Admin/Queues/Template.html?queue=$queue&Template=".$template_obj->id(),

Modified: rt/branches/3.999-DANGEROUS/html/Admin/Users/Modify.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Admin/Users/Modify.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Admin/Users/Modify.html	Sun Feb  3 00:25:21 2008
@@ -301,7 +301,7 @@
             $ARGS{'object-RT::Model::User-'.$val.'-CustomField-'.$1} = delete $ARGS{$key};
             }
         }
-        push @results, process_object_custom_field_updates( ARGSRef => \%ARGS, object => $user_object );
+        push @results, process_object_custom_field_updates( args_ref => \%ARGS, object => $user_object );
 	} else {
 		push @results, _('User could not be Created: %1', $msg);
 	}
@@ -334,11 +334,11 @@
 		    Address2 City State Zip Country 
 		   );
 
-    my @fieldresults = update_record_object ( AttributesRef => \@fields,
+    my @fieldresults = update_record_object ( attributes_ref => \@fields,
 					    object => $user_object,
-					    ARGSRef => \%ARGS );
+					    args_ref => \%ARGS );
     push (@results, at fieldresults);
-    push @results, process_object_custom_field_updates( ARGSRef => \%ARGS, object => $user_object );
+    push @results, process_object_custom_field_updates( args_ref => \%ARGS, object => $user_object );
 
 
     # {{{ Deal with special fields: privileged, enabled

Modified: rt/branches/3.999-DANGEROUS/html/Elements/GnuPG/SelectKeyForEncryption
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Elements/GnuPG/SelectKeyForEncryption	(original)
+++ rt/branches/3.999-DANGEROUS/html/Elements/GnuPG/SelectKeyForEncryption	Sun Feb  3 00:25:21 2008
@@ -50,7 +50,7 @@
 % } else {
 <select name="<% $name %>">
 %     foreach my $key (@keys) {
-<option value="<% $key->{'Fingerprint'} %>"><% $key->{'Fingerprint'} %> <% _("(trust: %1)", $key->{'TrustTerse'}) %></option>
+<option value="<% $key->{'fingerprint'} %>"><% $key->{'fingerprint'} %> <% _("(trust: %1)", $key->{'trust_terse'}) %></option>
 %     }
 </select>
 % }
@@ -62,13 +62,13 @@
 my %res = RT::Crypt::GnuPG::get_keys_for_encryption($email);
 # move the preferred key to the top of the list
 my @keys = map {
-               $_->{'Fingerprint'} eq ( $Default || '' )
+               $_->{'fingerprint'} eq ( $Default || '' )
                    ?  do { $d = $_; () }
                    : $_
            }
            @{ $res{'info'} };
 
- at keys = sort { $b->{'TrustLevel'} <=> $a->{'TrustLevel'} } @keys;
+ at keys = sort { $b->{'trust_level'} <=> $a->{'trust_level'} } @keys;
 
 unshift @keys, $d if defined $d;
 

Modified: rt/branches/3.999-DANGEROUS/html/Elements/GnuPG/SignEncryptWidget
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Elements/GnuPG/SignEncryptWidget	(original)
+++ rt/branches/3.999-DANGEROUS/html/Elements/GnuPG/SignEncryptWidget	Sun Feb  3 00:25:21 2008
@@ -15,13 +15,13 @@
 
 <%METHOD new>
 <%ARGS>
-$Arguments => {}
+$arguments => {}
 </%ARGS>
 <%INIT>
 return undef unless RT->config->get('GnuPG')->{'enable'};
 
 require RT::Crypt::GnuPG;
-return { %$Arguments };
+return { %$arguments };
 </%INIT>
 </%METHOD>
 
@@ -64,7 +64,7 @@
 <%METHOD Check>
 <%ARGS>
 $self      => undef
-$Operation => 'Update'
+$Operation => 'update'
 $ticket_obj => undef
 $queue_obj  => undef
 </%ARGS>
@@ -77,8 +77,8 @@
     $queue_obj ||= $ticket_obj->queue_obj
         if $ticket_obj;
 
-    my $address = $self->{'SignUsing'};
-    $address ||= ($self->{'UpdateType'}||'') eq "private"
+    my $address = $self->{'sign_using'};
+    $address ||= ($self->{'update_type'}||'') eq "private"
         ? ( $queue_obj->comment_address || RT->config->get('comment_address') )
         : ( $queue_obj->correspond_address || RT->config->get('correspond_address') );
 
@@ -86,8 +86,8 @@
         push @{ $self->{'GnuPGCanNotSignAs'} ||= [] }, $address;
         $checks_failure = 1;
     } else {
-        RT::Crypt::GnuPG::use_key_for_signing( $self->{'SignUsing'} )
-            if $self->{'SignUsing'};
+        RT::Crypt::GnuPG::use_key_for_signing( $self->{'sign_using'} )
+            if $self->{'sign_using'};
     }
 }
 
@@ -95,7 +95,7 @@
 
     my @recipients;
 
-    if ( $Operation eq 'Update' ) {
+    if ( $Operation eq 'update' ) {
         # skip any email addresses that we won't be sending mail to
         my %squelch = $m->comp(
             '/Ticket/Elements/PreviewScrips:SquelchRecipients',
@@ -108,7 +108,7 @@
             %$self, ticket_obj => $ticket_obj
         );
     }
-    elsif ( $Operation eq 'Create' ) {
+    elsif ( $Operation eq 'create' ) {
         @recipients = $m->comp(
             '/Ticket/Elements/PreviewScrips:GetRecipientsOnCreate',
             %$self,

Modified: rt/branches/3.999-DANGEROUS/html/Elements/GnuPGKeyIssues
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Elements/GnuPGKeyIssues	(original)
+++ rt/branches/3.999-DANGEROUS/html/Elements/GnuPGKeyIssues	Sun Feb  3 00:25:21 2008
@@ -66,18 +66,18 @@
 <ul>
 % foreach my $issue ( @$Issues ) {
 <li>
-% if ( $issue->{'User'} ) {
-User <a href="<% RT->config->get('WebPath') %>/Admin/Users/Modify.html?id=<% $issue->{'User'}->id %>"><&/Elements/ShowUser, User => $issue->{'User'} &></a> has a problem.
+% if ( $issue->{'user'} ) {
+User <a href="<% RT->config->get('WebPath') %>/Admin/Users/Modify.html?id=<% $issue->{'user'}->id %>"><&/Elements/ShowUser, User => $issue->{'user'} &></a> has a problem.
 % } else {
 There is a problem with key(s) for address <% $issue->{'email'} %>, but there is no user in the DB for this address.
 % }
-<% $issue->{'Message'} %>
+<% $issue->{'message'} %>
 <br />
 Select a key you want to use for encryption:
 <& /Elements/GnuPG/SelectKeyForEncryption,
     name         => 'UseKey-'. $issue->{'email'},
     email => $issue->{'email'},
-    Default      => ( $issue->{'User'}? $issue->{'User'}->preferred_key : undef ),
+    Default      => ( $issue->{'user'}? $issue->{'user'}->preferred_key : undef ),
 &>
 </li>
 % }

Modified: rt/branches/3.999-DANGEROUS/html/Elements/RT__Model__Ticket/ColumnMap
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Elements/RT__Model__Ticket/ColumnMap	(original)
+++ rt/branches/3.999-DANGEROUS/html/Elements/RT__Model__Ticket/ColumnMap	Sun Feb  3 00:25:21 2008
@@ -237,7 +237,7 @@
                 if (!defined $key{'info'}) {
                     $email .= _(" (no pubkey!)");
                 }
-                elsif ($key{'info'}{'TrustLevel'} == 0) {
+                elsif ($key{'info'}{'trust_level'} == 0) {
                     $email .= _(" (untrusted!)");
                 }
             }
@@ -254,7 +254,7 @@
             if (!defined $key{'info'}) {
                 $name .= _(" (no pubkey!)");
             }
-            elsif ($key{'info'}{'TrustLevel'} == 0) {
+            elsif ($key{'info'}{'trust_level'} == 0) {
                 $name .= _(" (untrusted!)");
             }
 

Modified: rt/branches/3.999-DANGEROUS/html/Elements/ValidateCustomFields
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Elements/ValidateCustomFields	(original)
+++ rt/branches/3.999-DANGEROUS/html/Elements/ValidateCustomFields	Sun Feb  3 00:25:21 2008
@@ -52,14 +52,14 @@
     my $field = $namePrefix . $CF->id . "-Value";
 
     my $value;
-    if ($ARGSRef->{"${field}s-Magic"} and exists $ARGSRef->{"${field}s"}) {
-        $value = $ARGSRef->{"${field}s"};
+    if ($args_ref->{"${field}s-Magic"} and exists $args_ref->{"${field}s"}) {
+        $value = $args_ref->{"${field}s"};
 
         # We only validate Single Combos -- multis can never be user input
         next if ref $value;
     }
     else {
-        $value = $ARGSRef->{$field};
+        $value = $args_ref->{$field};
     }
     $m->notes(('Field-' . $CF->id) => $value);
 
@@ -95,6 +95,6 @@
 </%INIT>
 <%ARGS>
 $CustomFields
-$ARGSRef
+$args_ref
 $namePrefix => "object-RT::Model::Ticket--CustomField-"
 </%ARGS>

Modified: rt/branches/3.999-DANGEROUS/html/Search/Bulk.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Search/Bulk.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Search/Bulk.html	Sun Feb  3 00:25:21 2008
@@ -270,25 +270,25 @@
 
     my @updateresults, process_update_message(
             ticket_obj => $Ticket,
-            ARGSRef   => \%ARGS,
+            args_ref   => \%ARGS,
         );
 
     #Update the basics.
     my @basicresults =
-      process_ticket_basics( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+      process_ticket_basics( ticket_obj => $Ticket, args_ref => \%ARGS );
     my @dateresults =
-      process_ticket_dates( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+      process_ticket_dates( ticket_obj => $Ticket, args_ref => \%ARGS );
 
     #Update the watchers
     my @watchresults =
-      process_ticket_watchers( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+      process_ticket_watchers( ticket_obj => $Ticket, args_ref => \%ARGS );
 
     foreach my $type qw(MergeInto DependsOn MemberOf RefersTo) {
         $ARGS{ $Ticket->id . "-" . $type } = $ARGS{"Ticket-$type"};
         $ARGS{ $type . "-" . $Ticket->id } = $ARGS{"$type-Ticket"};
     }
     @linkresults =
-      process_ticket_links( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+      process_ticket_links( ticket_obj => $Ticket, args_ref => \%ARGS );
     foreach my $type qw(MergeInto DependsOn MemberOf RefersTo) {
         delete $ARGS{ $type . "-" . $Ticket->id };
         delete $ARGS{ $Ticket->id . "-" . $type };

Modified: rt/branches/3.999-DANGEROUS/html/Search/Elements/BuildFormatString
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Search/Elements/BuildFormatString	(original)
+++ rt/branches/3.999-DANGEROUS/html/Search/Elements/BuildFormatString	Sun Feb  3 00:25:21 2008
@@ -117,7 +117,7 @@
     push @fields, "CustomField.{" . $CustomField->name . "}";
 }
 
-$m->callback( Fields => \@fields, ARGSRef => \%ARGS );
+$m->callback( Fields => \@fields, args_ref => \%ARGS );
 
 my ( @seen);
 

Modified: rt/branches/3.999-DANGEROUS/html/SelfService/Display.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/SelfService/Display.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/SelfService/Display.html	Sun Feb  3 00:25:21 2008
@@ -186,7 +186,7 @@
         $ARGS{UpdateAttachments} = $session{'Attachments'};
     }
     push @results, process_update_message(
-        ARGSRef   => \%ARGS,
+        args_ref   => \%ARGS,
         ticket_obj => $Ticket
     );
             delete $session{'Attachments'};
@@ -196,7 +196,7 @@
         delete $session{'Attachments'};
     }
 
-    my @cfupdates = process_object_custom_field_updates(object => $Ticket, ARGSRef => \%ARGS);
+    my @cfupdates = process_object_custom_field_updates(object => $Ticket, args_ref => \%ARGS);
     push (@results, @cfupdates);
 
     # }}}

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/Create.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/Create.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/Create.html	Sun Feb  3 00:25:21 2008
@@ -55,7 +55,7 @@
 <& /Elements/ListActions, actions => \@results &>
 <form action="<% RT->config->get('WebPath') %>/Ticket/Create.html" method="post" enctype="multipart/form-data" name="TicketCreate">
 <input type="hidden" class="hidden" name="id" value="new" />
-% $m->callback( Callbackname => 'FormStart', ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'FormStart', args_ref => \%ARGS );
 
 <& /Elements/GnuPG/SignEncryptWidget:ShowIssues, self => $gnupg_widget &>
 
@@ -319,7 +319,7 @@
 my $queue_obj = RT::Model::Queue->new();
 $queue_obj->load($queue) || abort(_("Queue could not be loaded."));
 
-$m->callback( queue_obj => $queue_obj, ARGSRef => \%ARGS );
+$m->callback( queue_obj => $queue_obj, args_ref => \%ARGS );
 
 my $CFs = $queue_obj->ticket_custom_fields();
 my $TxnCFs = $queue_obj->ticket_transaction_custom_fields();
@@ -327,7 +327,7 @@
 my $ValidCFs = $m->comp(
     '/Elements/ValidateCustomFields',
     CustomFields => $CFs,
-    ARGSRef => \%ARGS
+    args_ref => \%ARGS
 );
 
 # if no due date has been set explicitly, then use the
@@ -374,7 +374,7 @@
 
 my $checks_failure = 0;
 
-my $gnupg_widget = $m->comp('/Elements/GnuPG/SignEncryptWidget:new', Arguments => \%ARGS );
+my $gnupg_widget = $m->comp('/Elements/GnuPG/SignEncryptWidget:new', arguments => \%ARGS );
 $m->comp( '/Elements/GnuPG/SignEncryptWidget:Process',
     self      => $gnupg_widget,
     queue_obj  => $queue_obj,
@@ -384,7 +384,7 @@
 if ( !exists $ARGS{'AddMoreAttach'} && ($ARGS{'id'}||'') eq 'new' ) {
     my $status = $m->comp('/Elements/GnuPG/SignEncryptWidget:Check',
         self      => $gnupg_widget,
-        Operation => 'Create',
+        operation => 'create',
         queue_obj  => $queue_obj,
     );
     $checks_failure = 1 unless $status;

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/Display.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/Display.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/Display.html	Sun Feb  3 00:25:21 2008
@@ -52,7 +52,7 @@
     current_tab => 'Ticket/Display.html?id='.$ticket_obj->id,
     Title => _("#%1: %2", $ticket_obj->id, $ticket_obj->subject) &>
 
-% $m->callback(Callbackname => 'BeforeActionList', %ARGS, Actions => \@Actions, ARGSRef => \%ARGS, Ticket => $ticket_obj);
+% $m->callback(Callbackname => 'BeforeActionList', %ARGS, Actions => \@Actions, args_ref => \%ARGS, Ticket => $ticket_obj);
 
 <& /Elements/ListActions, actions => \@Actions &>
 <& Elements/ShowUpdateStatus, Ticket => $ticket_obj &>
@@ -91,7 +91,7 @@
 
 <%INIT>
 
-$m->callback( ticket_obj => $ticket_obj, ARGSRef => \%ARGS, Callbackname => 'Initial' );
+$m->callback( ticket_obj => $ticket_obj, args_ref => \%ARGS, Callbackname => 'Initial' );
 
 my (@Actions, $Tickets);  
 
@@ -126,7 +126,7 @@
 
     $m->callback( Callbackname => 'BeforeProcessArguments',
         ticket_obj => $ticket_obj, Tickets => $Tickets,
-        ActionsRef => \@Actions, ARGSRef => \%ARGS );
+        ActionsRef => \@Actions, args_ref => \%ARGS );
     if ( defined $ARGS{'Action'} ) {
         if ($ARGS{'Action'} =~ /^(steal|kill|take|set_old)$/) {
             my $action = $1;
@@ -137,7 +137,7 @@
 
     $m->callback(Callbackname => 'ProcessArguments', 
             Ticket => $ticket_obj, 
-            ARGSRef => \%ARGS, 
+            args_ref => \%ARGS, 
             Actions => \@Actions);
     
     $ARGS{'update_content'} =~ s/\r\n/\n/g if defined $ARGS{'update_content'};
@@ -149,15 +149,15 @@
     {
         $ARGS{UpdateAttachments} = $session{'Attachments'};
         push @Actions, process_update_message(
-            ARGSRef   => \%ARGS,
+            args_ref   => \%ARGS,
             Actions   => \@Actions,
             ticket_obj => $ticket_obj,
         );
         delete $session{'Attachments'};
     }
-    push @Actions, process_ticket_watchers(ARGSRef => \%ARGS, ticket_obj => $ticket_obj );
-    push @Actions, process_ticket_basics(   ARGSRef => \%ARGS, ticket_obj => $ticket_obj );
-    push @Actions, process_ticket_links(    ARGSRef => \%ARGS, ticket_obj => $ticket_obj );
+    push @Actions, process_ticket_watchers(args_ref => \%ARGS, ticket_obj => $ticket_obj );
+    push @Actions, process_ticket_basics(   args_ref => \%ARGS, ticket_obj => $ticket_obj );
+    push @Actions, process_ticket_links(    args_ref => \%ARGS, ticket_obj => $ticket_obj );
 
     # XXX: we shouldn't block actions here if user has no right to see the ticket,
     # but we should allow him to see actions he has done
@@ -178,7 +178,7 @@
     ticket_obj => \$ticket_obj,
     Tickets => \$Tickets,
     Actions => \@Actions,
-    ARGSRef => \%ARGS,
+    args_ref => \%ARGS,
 );
 
 # This code does automatic redirection if any updates happen. 

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/Elements/PreviewScrips
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/Elements/PreviewScrips	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/Elements/PreviewScrips	Sun Feb  3 00:25:21 2008
@@ -133,7 +133,7 @@
     bcc_message_to => $ARGS{'UpdateBcc'},
     mime_obj      => $Message,
     time_taken    => $ARGS{'UpdateTimeWorked'},
-    DryRun       => 1
+    dry_run       => 1
 );
 unless ( $Transaction ) {
     Jifty->log->error("Coulfn't fire '$action' action: $description");
@@ -202,10 +202,10 @@
 my ( $id, $txn, $msg ) = $ticket_obj->create(
     type            => $ARGS{'type'} || 'ticket',
     queue           => $ARGS{'queue'},
-    Owner           => $ARGS{'Owner'},
-    Requestor       => $ARGS{'Requestors'},
-    Cc              => $ARGS{'Cc'},
-    AdminCc         => $ARGS{'AdminCc'},
+    owner           => $ARGS{'Owner'},
+    requestor       => $ARGS{'Requestors'},
+    cc              => $ARGS{'Cc'},
+    admin_Cc         => $ARGS{'AdminCc'},
     initial_priority => $ARGS{'initial_priority'},
     final_priority   => $ARGS{'final_priority'},
     time_left        => $ARGS{'time_left'},
@@ -214,7 +214,7 @@
     subject         => $ARGS{'subject'},
     Status          => $ARGS{'Status'},
     mime_obj      => $Message,
-    DryRun       => 1
+    dry_run       => 1
 );
 unless ( $id && $txn ) {
     Jifty->log->error("Couldn't fire '$action' action: $msg");

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/Forward.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/Forward.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/Forward.html	Sun Feb  3 00:25:21 2008
@@ -51,11 +51,11 @@
     Title  => $Title,
 &>
 
-% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, ARGSRef => \%ARGS, Ticket => $ticket_obj);
+% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, args_ref => \%ARGS, Ticket => $ticket_obj);
 <& /Elements/ListActions, actions => \@results &>
 
 <form action="Forward.html" name="ForwardMessage" method="post">
-% $m->callback( Callbackname => 'FormStart', ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'FormStart', args_ref => \%ARGS );
 <input type="hidden" class="hidden" name="id" value="<% $id %>" /><br />
 <input type="hidden" class="hidden" name="QuoteTransaction" value="<% $ARGS{'QuoteTransaction'} %>" />
 

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/GnuPG.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/GnuPG.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/GnuPG.html	Sun Feb  3 00:25:21 2008
@@ -5,7 +5,7 @@
     Title => $title,
 &>
 
-% $m->callback( Callbackname => 'BeforeActionList', %ARGS, Actions => \@results, ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'BeforeActionList', %ARGS, Actions => \@results, args_ref => \%ARGS );
 <& /Elements/ListActions, actions => \@results &>
 <form method="post" action="<% RT->config->get('WebPath') . $m->request_comp->path %>?id=<% $id %>">
 <a href="<% RT->config->get('WebURL') %>/Ticket/Display.html?id=<% $txn->ticket %>#txn-<% $id %>">

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/History.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/History.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/History.html	Sun Feb  3 00:25:21 2008
@@ -50,7 +50,7 @@
     Ticket => $Ticket, current_tab => 'Ticket/History.html?id='.$Ticket->id, 
     Title => _("Ticket History # %1 %2", $Ticket->id, $Ticket->subject) &>
 
-% $m->callback(Callbackname => 'BeforeActionList', ARGSRef => \%ARGS, Ticket => $Ticket);
+% $m->callback(Callbackname => 'BeforeActionList', args_ref => \%ARGS, Ticket => $Ticket);
 
 
 <br />

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/Modify.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/Modify.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/Modify.html	Sun Feb  3 00:25:21 2008
@@ -50,11 +50,11 @@
     Ticket => $ticket_obj, current_subtab => "Ticket/Modify.html?id=".$ticket_obj->id, 
     Title => _('Modify ticket #%1', $ticket_obj->id) &>
 
-% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, ARGSRef => \%ARGS, Ticket => $ticket_obj);
+% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, args_ref => \%ARGS, Ticket => $ticket_obj);
 
 <& /Elements/ListActions, actions => \@results &>
 <form method="post" action="Modify.html" enctype="multipart/form-data">
-% $m->callback( Callbackname => 'FormStart', ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'FormStart', args_ref => \%ARGS );
 <input type="hidden" class="hidden" name="id" value="<% $ticket_obj->id %>" />
 
 <&| /Widgets/TitleBox, title => _('Modify ticket #%1',$ticket_obj->id) &>
@@ -70,10 +70,10 @@
 my $CustomFields = $ticket_obj->queue_obj->ticket_custom_fields();
 
 # Now let callbacks have a chance at editing %ARGS
-$m->callback( ticket_obj => $ticket_obj, CustomFields => $CustomFields, ARGSRef => \%ARGS );
+$m->callback( ticket_obj => $ticket_obj, CustomFields => $CustomFields, args_ref => \%ARGS );
 
-my @results = process_ticket_basics(ticket_obj => $ticket_obj, ARGSRef => \%ARGS);
-my @cf_results = process_object_custom_field_updates(object => $ticket_obj, ARGSRef => \%ARGS);
+my @results = process_ticket_basics(ticket_obj => $ticket_obj, args_ref => \%ARGS);
+my @cf_results = process_object_custom_field_updates(object => $ticket_obj, args_ref => \%ARGS);
 push (@results, @cf_results);
 
 # undef so that transaction_batch scrips run and update the ticket

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/ModifyAll.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/ModifyAll.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/ModifyAll.html	Sun Feb  3 00:25:21 2008
@@ -51,11 +51,11 @@
     current_tab => "Ticket/ModifyAll.html?id=".$Ticket->id, 
     Title => _("Ticket #%1 Jumbo update: %2", $Ticket->id, $Ticket->subject) &>
 
-% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, ARGSRef => \%ARGS, Ticket => $Ticket);
+% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, args_ref => \%ARGS, Ticket => $Ticket);
 <& /Elements/ListActions, actions => \@results &>
 
 <form method="post" action="ModifyAll.html" enctype="multipart/form-data">
-% $m->callback( Callbackname => 'FormStart', ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'FormStart', args_ref => \%ARGS );
 <input type="hidden" class="hidden" name="id" value="<%$Ticket->id%>" />
 
 <&| /Widgets/TitleBox, title => _('Modify ticket # %1', $Ticket->id) &>
@@ -148,7 +148,7 @@
                      $Ticket->current_user_has_right('ModifyTicket') );
 
 
-$m->callback( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+$m->callback( ticket_obj => $Ticket, args_ref => \%ARGS );
 my (@wresults, @results,  @dresults, @lresults, @cf_results);
 
 unless ($OnlySearchForPeople) {
@@ -162,10 +162,10 @@
 
     }
 
-    @wresults   = process_ticket_watchers( ticket_obj => $Ticket, ARGSRef => \%ARGS);
-    @cf_results = process_object_custom_field_updates( object => $Ticket, ARGSRef => \%ARGS);
-    @dresults   = process_ticket_dates( ticket_obj => $Ticket, ARGSRef => \%ARGS);
-    @lresults   = process_ticket_links( ticket_obj => $Ticket, ARGSRef => \%ARGS);
+    @wresults   = process_ticket_watchers( ticket_obj => $Ticket, args_ref => \%ARGS);
+    @cf_results = process_object_custom_field_updates( object => $Ticket, args_ref => \%ARGS);
+    @dresults   = process_ticket_dates( ticket_obj => $Ticket, args_ref => \%ARGS);
+    @lresults   = process_ticket_links( ticket_obj => $Ticket, args_ref => \%ARGS);
 
     if ($ARGS{'UpdateAttachment'}) {
         my $subject = "$ARGS{'UpdateAttachment'}";
@@ -183,8 +183,8 @@
         $ARGS{'UpdateAttachments'}->{ $subject } = $attachment;
     }
 
-    push @results, process_update_message( ticket_obj => $Ticket, ARGSRef=>\%ARGS );
-    push @results, process_ticket_basics( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+    push @results, process_update_message( ticket_obj => $Ticket, args_ref=>\%ARGS );
+    push @results, process_ticket_basics( ticket_obj => $Ticket, args_ref => \%ARGS );
 }
 push @results, @wresults;
 push @results, @dresults;

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/ModifyDates.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/ModifyDates.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/ModifyDates.html	Sun Feb  3 00:25:21 2008
@@ -51,11 +51,11 @@
     current_tab => "Ticket/ModifyDates.html?id=".$ticket_obj->id, 
     Title => _('Modify dates for #%1', $ticket_obj->id) &> 
 
-% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, ARGSRef => \%ARGS, Ticket => $ticket_obj);
+% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, args_ref => \%ARGS, Ticket => $ticket_obj);
 <& /Elements/ListActions, actions => \@results &>
 
 <form method="post" action="ModifyDates.html">
-% $m->callback( Callbackname => 'FormStart', ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'FormStart', args_ref => \%ARGS );
 <input type="hidden" class="hidden" name="id" value="<%$ticket_obj->id%>" />
 <&| /Widgets/TitleBox,title => _('Modify dates for ticket # %1', $ticket_obj->id) &>
 <& Elements/EditDates, ticket_obj => $ticket_obj &>
@@ -67,8 +67,8 @@
 <%INIT>
 
 my $ticket_obj = load_ticket($id);
-$m->callback( ticket_obj => $ticket_obj, ARGSRef => \%ARGS );
-my @results = process_ticket_dates( ticket_obj => $ticket_obj, ARGSRef => \%ARGS);
+$m->callback( ticket_obj => $ticket_obj, args_ref => \%ARGS );
+my @results = process_ticket_dates( ticket_obj => $ticket_obj, args_ref => \%ARGS);
 
 </%INIT>
 

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/ModifyLinks.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/ModifyLinks.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/ModifyLinks.html	Sun Feb  3 00:25:21 2008
@@ -51,12 +51,12 @@
     current_tab => "Ticket/ModifyLinks.html?id=".$Ticket->id, 
     Title => _("Link ticket #%1", $Ticket->id) &>
 
-% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, ARGSRef => \%ARGS, Ticket => $Ticket);
+% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, args_ref => \%ARGS, Ticket => $Ticket);
 <& /Elements/ListActions, actions => \@results &>
 
 <form action="ModifyLinks.html" method="post">
 <input type="hidden" class="hidden" name="id" value="<%$Ticket->id%>" />
-% $m->callback( Callbackname => 'FormStart', ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'FormStart', args_ref => \%ARGS );
 <&| /Widgets/TitleBox, title => _('Edit Links') &>
 <& /Elements/EditLinks, object => $Ticket, Merge => 1 &>
 </&>
@@ -71,8 +71,8 @@
 my $Ticket = load_ticket($id);
 
 my @results;  
-$m->callback( ticket_obj => $Ticket, ARGSRef => \%ARGS, Results => \@results );
-push @results, process_ticket_links( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+$m->callback( ticket_obj => $Ticket, args_ref => \%ARGS, Results => \@results );
+push @results, process_ticket_links( ticket_obj => $Ticket, args_ref => \%ARGS );
     
 </%INIT>
       

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/ModifyPeople.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/ModifyPeople.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/ModifyPeople.html	Sun Feb  3 00:25:21 2008
@@ -51,12 +51,12 @@
     current_tab => "Ticket/ModifyPeople.html?id=".$Ticket->id, 
     Title => _('Modify people related to ticket #%1', $Ticket->id) &>
 
-% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, ARGSRef => \%ARGS, Ticket => $Ticket);
+% $m->callback(Callbackname => 'BeforeActionList', Actions => \@results, args_ref => \%ARGS, Ticket => $Ticket);
 <& /Elements/ListActions, actions => \@results &>
 
 <form method="post" action="ModifyPeople.html">
 <input type="hidden" class="hidden" name="id" value="<%$Ticket->id%>" />
-% $m->callback( Callbackname => 'FormStart', ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'FormStart', args_ref => \%ARGS );
 <&| /Widgets/TitleBox, title => _('Modify people related to ticket #%1', $Ticket->id),   width => "100%", color=> "#333399" &>
 <& Elements/EditPeople, Ticket => $Ticket, UserField => $UserField, UserString => $UserString, UserOp => $UserOp, GroupString => $GroupString, GroupOp => $GroupOp, GroupField => $GroupField &>
 </&>
@@ -68,12 +68,12 @@
 my (@results, @wresults);
 
 my $Ticket = load_ticket($id);
-$m->callback( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+$m->callback( ticket_obj => $Ticket, args_ref => \%ARGS );
 
 # if we're trying to search for watchers and nothing else
 unless ($OnlySearchForPeople or $OnlySearchForGroup) {
-    @results = process_ticket_basics( ticket_obj => $Ticket, ARGSRef => \%ARGS);
-    @wresults = process_ticket_watchers( ticket_obj => $Ticket, ARGSRef => \%ARGS);
+    @results = process_ticket_basics( ticket_obj => $Ticket, args_ref => \%ARGS);
+    @wresults = process_ticket_watchers( ticket_obj => $Ticket, args_ref => \%ARGS);
 }
 
 push @results, @wresults;

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/Reminders.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/Reminders.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/Reminders.html	Sun Feb  3 00:25:21 2008
@@ -51,7 +51,7 @@
     current_tab => "Ticket/Reminders.html?id=".$Ticket->id, 
     Title => _("Reminders for ticket #%1", $Ticket->id) &>
     
-% $m->callback(Callbackname => 'BeforeActionList', ARGSRef => \%ARGS, Ticket => $Ticket);
+% $m->callback(Callbackname => 'BeforeActionList', args_ref => \%ARGS, Ticket => $Ticket);
     
 <form action="<%RT->config->get('WebPath')%>/Ticket/Reminders.html" method="post">
 <&|/Widgets/TitleBox, title => _("Reminders"),

Modified: rt/branches/3.999-DANGEROUS/html/Ticket/Update.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/Ticket/Update.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/Ticket/Update.html	Sun Feb  3 00:25:21 2008
@@ -50,12 +50,12 @@
     Ticket => $ticket_obj, 
     Title=> $title &>
     
-% $m->callback(Callbackname => 'BeforeActionList', ARGSRef => \%ARGS, Ticket => $ticket_obj);
+% $m->callback(Callbackname => 'BeforeActionList', args_ref => \%ARGS, Ticket => $ticket_obj);
 <& /Elements/ListActions, actions => \@results &>
 
 <form action="Update.html" name="TicketUpdate"
     method="post" enctype="multipart/form-data">
-% $m->callback( Callbackname => 'FormStart', ARGSRef => \%ARGS );
+% $m->callback( Callbackname => 'FormStart', args_ref => \%ARGS );
 <input type="hidden" class="hidden" name="QuoteTransaction" value="<% $ARGS{QuoteTransaction}||'' %>" />
 <input type="hidden" class="hidden" name="DefaultStatus" value="<% $DefaultStatus ||''%>" />
 <input type="hidden" class="hidden" name="Action" value="<% $ARGS{Action}||'' %>" />
@@ -161,7 +161,7 @@
 
 my $ticket_obj = load_ticket($id);
 
-$m->callback( Ticket => $ticket_obj, ARGSRef => \%ARGS, Callbackname => 'Initial' );
+$m->callback( Ticket => $ticket_obj, args_ref => \%ARGS, Callbackname => 'Initial' );
 
 unless($DefaultStatus){
     $DefaultStatus=($ARGS{'Status'} ||$ticket_obj->status());
@@ -236,7 +236,7 @@
 
 my @results;
 
-my $gnupg_widget = $m->comp('/Elements/GnuPG/SignEncryptWidget:new', Arguments => \%ARGS );
+my $gnupg_widget = $m->comp('/Elements/GnuPG/SignEncryptWidget:new', arguments => \%ARGS );
 $m->comp( '/Elements/GnuPG/SignEncryptWidget:Process',
     self => $gnupg_widget,
     ticket_obj => $ticket_obj,
@@ -250,7 +250,7 @@
 }
 
 if ( !$checks_failure && exists $ARGS{SubmitTicket} ) {
-    $m->callback( Ticket => $ticket_obj, ARGSRef => \%ARGS, Callbackname => 'BeforeDisplay' );
+    $m->callback( Ticket => $ticket_obj, args_ref => \%ARGS, Callbackname => 'BeforeDisplay' );
     return $m->comp('Display.html', ticket_obj => $ticket_obj, %ARGS);
 }
 

Modified: rt/branches/3.999-DANGEROUS/html/User/Groups/Modify.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/User/Groups/Modify.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/User/Groups/Modify.html	Sun Feb  3 00:25:21 2008
@@ -122,9 +122,9 @@
 if ($id) {
     
     my @fields = qw(description name );
-    my @fieldresults = update_record_object ( AttributesRef => \@fields,
+    my @fieldresults = update_record_object ( attributes_ref => \@fields,
 					    object => $Group,
-					    ARGSRef => \%ARGS );
+					    args_ref => \%ARGS );
     push (@results, at fieldresults);
 }
 

Modified: rt/branches/3.999-DANGEROUS/html/User/Prefs.html
==============================================================================
--- rt/branches/3.999-DANGEROUS/html/User/Prefs.html	(original)
+++ rt/branches/3.999-DANGEROUS/html/User/Prefs.html	Sun Feb  3 00:25:21 2008
@@ -222,12 +222,12 @@
         fields       => \@fields,
         results      => \@results,
         user_object      => $user_object,
-        ARGSRef      => \%ARGS,
+        args_ref      => \%ARGS,
     );
     
-    my @fieldresults = update_record_object ( AttributesRef => \@fields,
+    my @fieldresults = update_record_object ( attributes_ref => \@fields,
 					    object => $user_object,
-					    ARGSRef => \%ARGS );
+					    args_ref => \%ARGS );
     push (@results, at fieldresults);
 
 

Modified: rt/branches/3.999-DANGEROUS/lib/RT/Interface/Web.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Interface/Web.pm	(original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Interface/Web.pm	Sun Feb  3 00:25:21 2008
@@ -468,7 +468,7 @@
 
 =head2 process_update_message
 
-Takes paramhash with fields ARGSRef, ticket_obj and SkipSignatureOnly.
+Takes paramhash with fields args_ref, ticket_obj and SkipSignatureOnly.
 
 Don't write message if it only contains current user's signature and
 SkipSignatureOnly argument is true. Function anyway adds attachments
@@ -481,26 +481,26 @@
 
     #TODO document what else this takes.
     my %args = (
-        ARGSRef           => undef,
+        args_ref           => undef,
         ticket_obj        => undef,
         SkipSignatureOnly => 1,
         @_
     );
 
-    if ( $args{ARGSRef}->{'UpdateAttachments'}
-        && !keys %{ $args{ARGSRef}->{'UpdateAttachments'} } )
+    if ( $args{args_ref}->{'UpdateAttachments'}
+        && !keys %{ $args{args_ref}->{'UpdateAttachments'} } )
     {
-        delete $args{ARGSRef}->{'UpdateAttachments'};
+        delete $args{args_ref}->{'UpdateAttachments'};
     }
 
     #Make the update content have no 'weird' newlines in it
     return ()
-        unless $args{ARGSRef}->{'UpdateTimeWorked'}
-            || $args{ARGSRef}->{'UpdateAttachments'}
-            || $args{ARGSRef}->{'update_content'};
+        unless $args{args_ref}->{'UpdateTimeWorked'}
+            || $args{args_ref}->{'UpdateAttachments'}
+            || $args{args_ref}->{'update_content'};
 
-    $args{ARGSRef}->{'update_content'} =~ s/\r+\n/\n/g
-        if $args{ARGSRef}->{'update_content'};
+    $args{args_ref}->{'update_content'} =~ s/\r+\n/\n/g
+        if $args{args_ref}->{'update_content'};
 
     # skip updates if the content contains only user's signature
     # and we don't update other fields
@@ -508,26 +508,26 @@
         my $sig = $args{'ticket_obj'}->current_user->user_object->signature
             || '';
         $sig =~ s/^\s*|\s*$//g;
-        if ( $args{ARGSRef}->{'update_content'} =~ /^\s*(--)?\s*\Q$sig\E\s*$/ )
+        if ( $args{args_ref}->{'update_content'} =~ /^\s*(--)?\s*\Q$sig\E\s*$/ )
         {
             return ()
-                unless $args{ARGSRef}->{'UpdateTimeWorked'}
-                    || $args{ARGSRef}->{'UpdateAttachments'};
+                unless $args{args_ref}->{'UpdateTimeWorked'}
+                    || $args{args_ref}->{'UpdateAttachments'};
 
             # we have to create transaction, but we don't create attachment
             # XXX: this couldn't work as expected
-            $args{ARGSRef}->{'update_content'} = '';
+            $args{args_ref}->{'update_content'} = '';
         }
     }
 
-    if ( $args{ARGSRef}->{'Updatesubject'} eq $args{'ticket_obj'}->subject ) {
-        $args{ARGSRef}->{'Updatesubject'} = undef;
+    if ( $args{args_ref}->{'Updatesubject'} eq $args{'ticket_obj'}->subject ) {
+        $args{args_ref}->{'Updatesubject'} = undef;
     }
 
     my $Message = make_mime_entity(
-        subject => $args{ARGSRef}->{'Updatesubject'},
-        Body    => $args{ARGSRef}->{'update_content'},
-        type    => $args{ARGSRef}->{'Updatecontent_type'},
+        subject => $args{args_ref}->{'Updatesubject'},
+        Body    => $args{args_ref}->{'update_content'},
+        type    => $args{args_ref}->{'Updatecontent_type'},
     );
 
     $Message->head->add(
@@ -536,8 +536,8 @@
         )
     );
     my $old_txn = RT::Model::Transaction->new();
-    if ( $args{ARGSRef}->{'QuoteTransaction'} ) {
-        $old_txn->load( $args{ARGSRef}->{'QuoteTransaction'} );
+    if ( $args{args_ref}->{'QuoteTransaction'} ) {
+        $old_txn->load( $args{args_ref}->{'QuoteTransaction'} );
     } else {
         $old_txn = $args{ticket_obj}->transactions->first();
     }
@@ -549,36 +549,36 @@
         );
     }
 
-    if ( $args{ARGSRef}->{'UpdateAttachments'} ) {
+    if ( $args{args_ref}->{'UpdateAttachments'} ) {
         $Message->make_multipart;
         $Message->add_part($_)
-            foreach values %{ $args{ARGSRef}->{'UpdateAttachments'} };
+            foreach values %{ $args{args_ref}->{'UpdateAttachments'} };
     }
 
-    if ( $args{ARGSRef}->{'AttachTickets'} ) {
+    if ( $args{args_ref}->{'AttachTickets'} ) {
         require RT::ScripAction::SendEmail;
         RT::ScripAction::SendEmail->attach_tickets(
             RT::ScripAction::SendEmail->attach_tickets,
-            ref $args{ARGSRef}->{'AttachTickets'}
-            ? @{ $args{ARGSRef}->{'AttachTickets'} }
-            : ( $args{ARGSRef}->{'AttachTickets'} )
+            ref $args{args_ref}->{'AttachTickets'}
+            ? @{ $args{args_ref}->{'AttachTickets'} }
+            : ( $args{args_ref}->{'AttachTickets'} )
         );
     }
 
-    my $bcc = $args{ARGSRef}->{'UpdateBcc'};
-    my $cc  = $args{ARGSRef}->{'update_cc'};
+    my $bcc = $args{args_ref}->{'UpdateBcc'};
+    my $cc  = $args{args_ref}->{'update_cc'};
 
     my %message_args = (
         cc_message_to  => $cc,
         bcc_message_to => $bcc,
-        sign         => $args{ARGSRef}->{'sign'},
-        encrypt      => $args{ARGSRef}->{'encrypt'},
+        sign         => $args{args_ref}->{'sign'},
+        encrypt      => $args{args_ref}->{'encrypt'},
         mime_obj      => $Message,
-        time_taken    => $args{ARGSRef}->{'UpdateTimeWorked'}
+        time_taken    => $args{args_ref}->{'UpdateTimeWorked'}
     );
 
     unless ( $args{'ARGRef'}->{'UpdateIgnoreAddressCheckboxes'} ) {
-        foreach my $key ( keys %{ $args{ARGSRef} } ) {
+        foreach my $key ( keys %{ $args{args_ref} } ) {
             next unless $key =~ /^Update(cc|Bcc)-(.*)$/;
 
             my $var   = ucfirst($1) . 'MessageTo';
@@ -592,16 +592,16 @@
     }
 
     my @results;
-    if ( $args{ARGSRef}->{'UpdateType'} =~ /^(private|public)$/ ) {
+    if ( $args{args_ref}->{'UpdateType'} =~ /^(private|public)$/ ) {
         my ( $Transaction, $description, $object )
             = $args{ticket_obj}->comment(%message_args);
         push( @results, $description );
-        $object->update_custom_fields( ARGSRef => $args{ARGSRef} ) if $object;
-    } elsif ( $args{ARGSRef}->{'UpdateType'} eq 'response' ) {
+        $object->update_custom_fields( args_ref => $args{args_ref} ) if $object;
+    } elsif ( $args{args_ref}->{'UpdateType'} eq 'response' ) {
         my ( $Transaction, $description, $object )
             = $args{ticket_obj}->correspond(%message_args);
         push( @results, $description );
-        $object->update_custom_fields( ARGSRef => $args{ARGSRef} ) if $object;
+        $object->update_custom_fields( args_ref => $args{args_ref} ) if $object;
     } else {
         push( @results,
             _("Update type was neither correspondence nor comment.") . " "
@@ -782,9 +782,9 @@
 
 # {{{ sub UpdateRecordObj
 
-=head2 UpdateRecordObj ( ARGSRef => \%ARGS, object => RT::Record, AttributesRef => \@attribs)
+=head2 UpdateRecordObj ( args_ref => \%ARGS, object => RT::Record, attributes_ref => \@attribs)
 
- at attribs is a list of ticket fields to check and update if they differ from the  B<object>'s current values. ARGSRef is a ref to HTML::Mason's %ARGS.
+ at attribs is a list of ticket fields to check and update if they differ from the  B<object>'s current values. args_ref is a ref to HTML::Mason's %ARGS.
 
 Returns an array of success/failure messages
 
@@ -792,8 +792,8 @@
 
 sub update_record_object {
     my %args = (
-        ARGSRef         => undef,
-        AttributesRef   => undef,
+        args_ref         => undef,
+        attributes_ref   => undef,
         object          => undef,
         AttributePrefix => undef,
         @_
@@ -801,8 +801,8 @@
 
     my $object  = $args{'object'};
     my @results = $object->update(
-        AttributesRef   => $args{'AttributesRef'},
-        ARGSRef         => $args{'ARGSRef'},
+        attributes_ref   => $args{'attributes_ref'},
+        args_ref         => $args{'args_ref'},
         AttributePrefix => $args{'AttributePrefix'},
     );
 
@@ -816,34 +816,34 @@
 sub process_custom_field_updates {
     my %args = (
         CustomFieldObj => undef,
-        ARGSRef        => undef,
+        args_ref        => undef,
         @_
     );
 
     my $object  = $args{'CustomFieldObj'};
-    my $ARGSRef = $args{'ARGSRef'};
+    my $args_ref = $args{'args_ref'};
 
     my @attribs = qw(name type description queue sort_order);
     my @results = update_record_object(
-        AttributesRef => \@attribs,
+        attributes_ref => \@attribs,
         object        => $object,
-        ARGSRef       => $ARGSRef
+        args_ref       => $args_ref
     );
 
     my $prefix = "CustomField-" . $object->id;
-    if ( $ARGSRef->{"$prefix-AddValue-name"} ) {
+    if ( $args_ref->{"$prefix-AddValue-name"} ) {
         my ( $addval, $addmsg ) = $object->add_value(
-            name        => $ARGSRef->{"$prefix-AddValue-name"},
-            description => $ARGSRef->{"$prefix-AddValue-Description"},
-            sort_order   => $ARGSRef->{"$prefix-AddValue-sort_order"},
+            name        => $args_ref->{"$prefix-AddValue-name"},
+            description => $args_ref->{"$prefix-AddValue-Description"},
+            sort_order   => $args_ref->{"$prefix-AddValue-sort_order"},
         );
         push( @results, $addmsg );
     }
 
     my @delete_values
-        = ( ref $ARGSRef->{"$prefix-DeleteValue"} eq 'ARRAY' )
-        ? @{ $ARGSRef->{"$prefix-DeleteValue"} }
-        : ( $ARGSRef->{"$prefix-DeleteValue"} );
+        = ( ref $args_ref->{"$prefix-DeleteValue"} eq 'ARRAY' )
+        ? @{ $args_ref->{"$prefix-DeleteValue"} }
+        : ( $args_ref->{"$prefix-DeleteValue"} );
 
     foreach my $id (@delete_values) {
         next unless defined $id;
@@ -853,7 +853,7 @@
 
     my $vals = $object->values();
     while ( my $cfv = $vals->next() ) {
-        if ( my $so = $ARGSRef->{ "$prefix-sort_order" . $cfv->id } ) {
+        if ( my $so = $args_ref->{ "$prefix-sort_order" . $cfv->id } ) {
             if ( $cfv->sort_order != $so ) {
                 my ( $err, $msg ) = $cfv->set_sort_order($so);
                 push( @results, $msg );
@@ -868,7 +868,7 @@
 
 # {{{ sub process_ticket_basics
 
-=head2 process_ticket_basics ( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+=head2 process_ticket_basics ( ticket_obj => $Ticket, args_ref => \%ARGS );
 
 Returns an array of results messages.
 
@@ -878,12 +878,12 @@
 
     my %args = (
         ticket_obj => undef,
-        ARGSRef    => undef,
+        args_ref    => undef,
         @_
     );
 
     my $ticket_obj = $args{'ticket_obj'};
-    my $ARGSRef    = $args{'ARGSRef'};
+    my $args_ref    = $args{'args_ref'};
 
     # {{{ Set basic fields
     my @attribs = qw(
@@ -898,38 +898,38 @@
         queue
     );
 
-    if ( $ARGSRef->{'queue'} and ( $ARGSRef->{'queue'} !~ /^(\d+)$/ ) ) {
+    if ( $args_ref->{'queue'} and ( $args_ref->{'queue'} !~ /^(\d+)$/ ) ) {
         my $tempqueue
             = RT::Model::Queue->new( current_user => RT->system_user );
-        $tempqueue->load( $ARGSRef->{'queue'} );
+        $tempqueue->load( $args_ref->{'queue'} );
         if ( $tempqueue->id ) {
-            $ARGSRef->{'queue'} = $tempqueue->id;
+            $args_ref->{'queue'} = $tempqueue->id;
         }
     }
 
     # Status isn't a field that can be set to a null value.
     # RT core complains if you try
-    delete $ARGSRef->{'Status'} unless $ARGSRef->{'Status'};
+    delete $args_ref->{'Status'} unless $args_ref->{'Status'};
 
     my @results = update_record_object(
-        AttributesRef => \@attribs,
+        attributes_ref => \@attribs,
         object        => $ticket_obj,
-        ARGSRef       => $ARGSRef,
+        args_ref       => $args_ref,
     );
 
     # We special case owner changing, so we can use ForceownerChange
-    if ( $ARGSRef->{'owner'}
-        && ( $ticket_obj->owner != $ARGSRef->{'owner'} ) )
+    if ( $args_ref->{'owner'}
+        && ( $ticket_obj->owner != $args_ref->{'owner'} ) )
     {
         my ($ChownType);
-        if ( $ARGSRef->{'ForceownerChange'} ) {
+        if ( $args_ref->{'ForceownerChange'} ) {
             $ChownType = "Force";
         } else {
             $ChownType = "Give";
         }
 
         my ( $val, $msg )
-            = $ticket_obj->set_owner( $ARGSRef->{'owner'}, $ChownType );
+            = $ticket_obj->set_owner( $args_ref->{'owner'}, $ChownType );
         push( @results, $msg );
     }
 
@@ -943,37 +943,37 @@
 sub process_ticket_custom_field_updates {
     my %args = @_;
     $args{'object'} = delete $args{'ticket_obj'};
-    my $ARGSRef = { %{ $args{'ARGSRef'} } };
+    my $args_ref = { %{ $args{'args_ref'} } };
 
     # Build up a list of objects that we want to work with
     my %custom_fields_to_mod;
-    foreach my $arg ( keys %$ARGSRef ) {
+    foreach my $arg ( keys %$args_ref ) {
         if ( $arg =~ /^Ticket-(\d+-.*)/ ) {
-            $ARGSRef->{"object-RT::Model::Ticket-$1"}
-                = delete $ARGSRef->{$arg};
+            $args_ref->{"object-RT::Model::Ticket-$1"}
+                = delete $args_ref->{$arg};
         } elsif ( $arg =~ /^CustomField-(\d+-.*)/ ) {
-            $ARGSRef->{"object-RT::Model::Ticket--$1"}
-                = delete $ARGSRef->{$arg};
+            $args_ref->{"object-RT::Model::Ticket--$1"}
+                = delete $args_ref->{$arg};
         }
     }
 
-    return process_object_custom_field_updates( %args, ARGSRef => $ARGSRef );
+    return process_object_custom_field_updates( %args, args_ref => $args_ref );
 }
 
 sub process_object_custom_field_updates {
     my %args    = @_;
-    my $ARGSRef = $args{'ARGSRef'};
+    my $args_ref = $args{'args_ref'};
     my @results;
 
     # Build up a list of objects that we want to work with
     my %custom_fields_to_mod;
-    foreach my $arg ( keys %$ARGSRef ) {
+    foreach my $arg ( keys %$args_ref ) {
 
     # format: object-<object class>-<object id>-CustomField-<CF id>-<commands>
         next unless $arg =~ /^object-([\w:]+)-(\d*)-CustomField-(\d+)-(.*)$/;
 
 # For each of those objects, find out what custom fields we want to work with.
-        $custom_fields_to_mod{$1}{ $2 || 0 }{$3}{$4} = $ARGSRef->{$arg};
+        $custom_fields_to_mod{$1}{ $2 || 0 }{$3}{$4} = $args_ref->{$arg};
     }
 
     # For each of those objects
@@ -1156,7 +1156,7 @@
 
 # {{{ sub process_ticket_watchers
 
-=head2 process_ticket_watchers ( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+=head2 process_ticket_watchers ( ticket_obj => $Ticket, args_ref => \%ARGS );
 
 Returns an array of results messages.
 
@@ -1165,17 +1165,17 @@
 sub process_ticket_watchers {
     my %args = (
         ticket_obj => undef,
-        ARGSRef    => undef,
+        args_ref    => undef,
         @_
     );
     my (@results);
 
     my $Ticket  = $args{'ticket_obj'};
-    my $ARGSRef = $args{'ARGSRef'};
+    my $args_ref = $args{'args_ref'};
 
     # Munge watchers
 
-    foreach my $key ( keys %$ARGSRef ) {
+    foreach my $key ( keys %$args_ref ) {
 
         # Delete deletable watchers
         if ( $key =~ /^Ticket-DeleteWatcher-Type-(.*)-Principal-(\d+)$/ ) {
@@ -1189,21 +1189,21 @@
         # Delete watchers in the simple style demanded by the bulk manipulator
         elsif ( $key =~ /^Delete(requestor|cc|admin_cc)$/ ) {
             my ( $code, $msg ) = $Ticket->delete_watcher(
-                email => $ARGSRef->{$key},
+                email => $args_ref->{$key},
                 type  => $1
             );
             push @results, $msg;
         }
 
         # Add new wathchers by email address
-        elsif ( ( $ARGSRef->{$key} || '' ) =~ /^(?:admin_cc|cc|requestor)$/
+        elsif ( ( $args_ref->{$key} || '' ) =~ /^(?:admin_cc|cc|requestor)$/
             and $key =~ /^WatcherTypeEmail(\d*)$/ )
         {
 
             #They're in this order because otherwise $1 gets clobbered :/
             my ( $code, $msg ) = $Ticket->add_watcher(
-                type  => $ARGSRef->{$key},
-                email => $ARGSRef->{ "WatcherAddressEmail" . $1 }
+                type  => $args_ref->{$key},
+                email => $args_ref->{ "WatcherAddressEmail" . $1 }
             );
             push @results, $msg;
         }
@@ -1212,7 +1212,7 @@
         elsif ( $key =~ /^Add(requestor|cc|admin_cc)$/ ) {
             my ( $code, $msg ) = $Ticket->add_watcher(
                 type  => $1,
-                email => $ARGSRef->{$key}
+                email => $args_ref->{$key}
             );
             push @results, $msg;
         }
@@ -1220,7 +1220,7 @@
         # Add new  watchers by owner
         elsif ( $key =~ /^Ticket-AddWatcher-Principal-(\d*)$/ ) {
             my $principal_id = $1;
-            my $form         = $ARGSRef->{$key};
+            my $form         = $args_ref->{$key};
             foreach my $value ( ref($form) ? @{$form} : ($form) ) {
                 next unless $value =~ /^(?:admin_cc|cc|requestor)$/i;
 
@@ -1240,7 +1240,7 @@
 
 # {{{ sub process_ticket_dates
 
-=head2 process_ticket_dates ( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+=head2 process_ticket_dates ( ticket_obj => $Ticket, args_ref => \%ARGS );
 
 Returns an array of results messages.
 
@@ -1249,12 +1249,12 @@
 sub process_ticket_dates {
     my %args = (
         ticket_obj => undef,
-        ARGSRef    => undef,
+        args_ref    => undef,
         @_
     );
 
     my $Ticket  = $args{'ticket_obj'};
-    my $ARGSRef = $args{'ARGSRef'};
+    my $args_ref = $args{'args_ref'};
 
     my (@results);
 
@@ -1269,15 +1269,15 @@
 
     #Run through each field in this list. update the value if apropriate
     foreach my $field (@date_fields) {
-        next unless exists $ARGSRef->{ $field . '_Date' };
-        next if $ARGSRef->{ $field . '_Date' } eq '';
+        next unless exists $args_ref->{ $field . '_Date' };
+        next if $args_ref->{ $field . '_Date' } eq '';
 
         my ( $code, $msg );
 
         my $DateObj = RT::Date->new();
         $DateObj->set(
             format => 'unknown',
-            Value  => $ARGSRef->{ $field . '_Date' }
+            Value  => $args_ref->{ $field . '_Date' }
         );
 
         my $obj = $field . "Obj";
@@ -1298,7 +1298,7 @@
 
 # {{{ sub process_ticket_links
 
-=head2 process_ticket_links ( ticket_obj => $Ticket, ARGSRef => \%ARGS );
+=head2 process_ticket_links ( ticket_obj => $Ticket, args_ref => \%ARGS );
 
 Returns an array of results messages.
 
@@ -1307,21 +1307,21 @@
 sub process_ticket_links {
     my %args = (
         ticket_obj => undef,
-        ARGSRef    => undef,
+        args_ref    => undef,
         @_
     );
 
     my $Ticket  = $args{'ticket_obj'};
-    my $ARGSRef = $args{'ARGSRef'};
+    my $args_ref = $args{'args_ref'};
 
     my (@results)
-        = process_record_links( RecordObj => $Ticket, ARGSRef => $ARGSRef );
+        = process_record_links( RecordObj => $Ticket, args_ref => $args_ref );
 
     #Merge if we need to
-    if ( $ARGSRef->{ $Ticket->id . "-MergeInto" } ) {
-        $ARGSRef->{ $Ticket->id . "-MergeInto" } =~ s/\s+//g;
+    if ( $args_ref->{ $Ticket->id . "-MergeInto" } ) {
+        $args_ref->{ $Ticket->id . "-MergeInto" } =~ s/\s+//g;
         my ( $val, $msg )
-            = $Ticket->merge_into( $ARGSRef->{ $Ticket->id . "-MergeInto" } );
+            = $Ticket->merge_into( $args_ref->{ $Ticket->id . "-MergeInto" } );
         push @results, $msg;
     }
 
@@ -1333,17 +1333,17 @@
 sub process_record_links {
     my %args = (
         RecordObj => undef,
-        ARGSRef   => undef,
+        args_ref   => undef,
         @_
     );
 
     my $Record  = $args{'RecordObj'};
-    my $ARGSRef = $args{'ARGSRef'};
+    my $args_ref = $args{'args_ref'};
 
     my (@results);
 
     # Delete links that are gone gone gone.
-    foreach my $arg ( keys %$ARGSRef ) {
+    foreach my $arg ( keys %$args_ref ) {
         if ( $arg =~ /delete_link-(.*?)-(DependsOn|MemberOf|RefersTo)-(.*)$/ )
         {
             my $base   = $1;
@@ -1368,9 +1368,9 @@
     my @linktypes = qw( DependsOn MemberOf RefersTo );
 
     foreach my $linktype (@linktypes) {
-        if ( $ARGSRef->{ $Record->id . "-$linktype" } ) {
+        if ( $args_ref->{ $Record->id . "-$linktype" } ) {
             for my $luri (
-                split( / /, $ARGSRef->{ $Record->id . "-$linktype" } ) )
+                split( / /, $args_ref->{ $Record->id . "-$linktype" } ) )
             {
                 $luri =~ s/\s*$//;    # Strip trailing whitespace
                 my ( $val, $msg ) = $Record->add_link(
@@ -1380,10 +1380,10 @@
                 push @results, $msg;
             }
         }
-        if ( $ARGSRef->{ "$linktype-" . $Record->id } ) {
+        if ( $args_ref->{ "$linktype-" . $Record->id } ) {
 
             for my $luri (
-                split( / /, $ARGSRef->{ "$linktype-" . $Record->id } ) )
+                split( / /, $args_ref->{ "$linktype-" . $Record->id } ) )
             {
                 my ( $val, $msg ) = $Record->add_link(
                     base => $luri,

Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/Transaction.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/User.pm	(original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/User.pm	Sun Feb  3 00:25:21 2008
@@ -1402,12 +1402,12 @@
     return undef if @keys == 0;
 
     if ( @keys == 1 ) {
-        $prefkey = $keys[0]->{'Fingerprint'};
+        $prefkey = $keys[0]->{'fingerprint'};
     } else {
 
         # prefer the maximally trusted key
-        @keys = sort { $b->{'TrustLevel'} <=> $a->{'TrustLevel'} } @keys;
-        $prefkey = $keys[0]->{'Fingerprint'};
+        @keys = sort { $b->{'trust_level'} <=> $a->{'trust_level'} } @keys;
+        $prefkey = $keys[0]->{'fingerprint'};
     }
 
     $self->set_attribute( name => 'preferred_key', content => $prefkey );

Modified: rt/branches/3.999-DANGEROUS/lib/RT/Record.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/Record.pm	(original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Record.pm	Sun Feb  3 00:25:21 2008
@@ -729,10 +729,10 @@
 Updates fields on an object for you using the proper set methods,
 skipping unchanged values.
 
- ARGSRef => a hashref of attributes => value for the update
- AttributesRef => an arrayref of keys in ARGSRef that should be updated
- AttributePrefix => a prefix that should be added to the attributes in AttributesRef
-                    when looking up values in ARGSRef
+ args_ref => a hashref of attributes => value for the update
+ attributes_ref => an arrayref of keys in args_ref that should be updated
+ AttributePrefix => a prefix that should be added to the attributes in attributes_ref
+                    when looking up values in args_ref
                     Bare attributes are tried before prefixed attributes
 
 Returns a list of localized results of the update
@@ -751,22 +751,22 @@
     );
 
     my $attributes = $args{'attributes_ref'};
-    my $ARGSRef    = $args{'args_ref'};
+    my $args_ref    = $args{'args_ref'};
     my @results;
 
     foreach my $attribute (@$attributes) {
         my $value;
-        if ( defined $ARGSRef->{$attribute} ) {
-            $value = $ARGSRef->{$attribute};
+        if ( defined $args_ref->{$attribute} ) {
+            $value = $args_ref->{$attribute};
         } elsif (
             defined( $args{'attribute_prefix'} )
             && defined(
-                $ARGSRef->{ $args{'attribute_prefix'} . "-" . $attribute }
+                $args_ref->{ $args{'attribute_prefix'} . "-" . $attribute }
             )
             )
         {
             $value
-                = $ARGSRef->{ $args{'attribute_prefix'} . "-" . $attribute };
+                = $args_ref->{ $args{'attribute_prefix'} . "-" . $attribute };
 
         } else {
             next;

Modified: rt/branches/3.999-DANGEROUS/lib/RT/ScripAction/CreateTickets.pm
==============================================================================
--- rt/branches/3.999-DANGEROUS/lib/RT/ScripAction/CreateTickets.pm	(original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/ScripAction/CreateTickets.pm	Sun Feb  3 00:25:21 2008
@@ -472,8 +472,8 @@
             }
         }
         push @results, $T::Tickets{$template_id}->update(
-            AttributesRef => \@attribs,
-            ARGSRef       => $ticketargs
+            attributes_ref => \@attribs,
+            args_ref       => $ticketargs
         );
 
         if ( $ticketargs->{'owner'} ) {

Modified: rt/branches/3.999-DANGEROUS/t/api/cf_transaction.t
==============================================================================
--- rt/branches/3.999-DANGEROUS/t/api/cf_transaction.t	(original)
+++ rt/branches/3.999-DANGEROUS/t/api/cf_transaction.t	Sun Feb  3 00:25:21 2008
@@ -48,7 +48,7 @@
 
 # Old API
 my %cf_updates = ( 'CustomField-'.$cf->id => 'Testing');
-$trans->update_custom_fields( ARGSRef => \%cf_updates);
+$trans->update_custom_fields( args_ref => \%cf_updates);
 
  $values = $trans->custom_field_values($txn_cf->id);
 is ($values->count, 1, "It has one value");

Modified: rt/branches/3.999-DANGEROUS/t/web/gnupg-outgoing.t
==============================================================================
--- rt/branches/3.999-DANGEROUS/t/web/gnupg-outgoing.t	(original)
+++ rt/branches/3.999-DANGEROUS/t/web/gnupg-outgoing.t	Sun Feb  3 00:25:21 2008
@@ -85,7 +85,7 @@
     my ($id) = $ticket->create(
         subject   => 'test',
         queue     => $queue->id,
-        Requestor => 'rt-test at example.com',
+        requestor => 'rt-test at example.com',
     );
     ok $id, 'ticket created';
 
@@ -121,7 +121,7 @@
     ($tid) = $ticket->create(
         subject   => 'test',
         queue     => $queue->id,
-        Requestor => 'rt-test at example.com',
+        requestor => 'rt-test at example.com',
     );
     ok $tid, 'ticket created';
 }

Modified: rt/branches/3.999-DANGEROUS/t/web/gnupg-select-keys-on-create.t
==============================================================================
--- rt/branches/3.999-DANGEROUS/t/web/gnupg-select-keys-on-create.t	(original)
+++ rt/branches/3.999-DANGEROUS/t/web/gnupg-select-keys-on-create.t	Sun Feb  3 00:25:21 2008
@@ -66,7 +66,7 @@
     RT::Test->import_gnupg_key('rt-recipient at example.com');
     RT::Test->trust_gnupg_key('rt-recipient at example.com');
     my %res = RT::Crypt::GnuPG::get_keys_info('rt-recipient at example.com');
-    is $res{'info'}[0]{'TrustTerse'}, 'ultimate', 'ultimately trusted key';
+    is $res{'info'}[0]{'trust_terse'}, 'ultimate', 'ultimately trusted key';
 }
 
 diag "check that things don't work if there is no key";
@@ -100,8 +100,8 @@
 {
     RT::Test->import_gnupg_key('rt-test at example.com', 'public');
     my %res = RT::Crypt::GnuPG::get_keys_info('rt-test at example.com');
-    is $res{'info'}[0]{'TrustLevel'}, 0, 'is not trusted key';
-    $fpr1 = $res{'info'}[0]{'Fingerprint'};
+    is $res{'info'}[0]{'trust_level'}, 0, 'is not trusted key';
+    $fpr1 = $res{'info'}[0]{'fingerprint'};
 }
 
 diag "check that things still doesn't work if key is not trusted";
@@ -147,8 +147,8 @@
 {
     RT::Test->import_gnupg_key('rt-test at example.com.2', 'public');
     my %res = RT::Crypt::GnuPG::get_keys_info('rt-test at example.com');
-    is $res{'info'}[1]{'TrustLevel'}, 0, 'is not trusted key';
-    $fpr2 = $res{'info'}[2]{'Fingerprint'};
+    is $res{'info'}[1]{'trust_level'}, 0, 'is not trusted key';
+    $fpr2 = $res{'info'}[2]{'fingerprint'};
 }
 
 diag "check that things still doesn't work if two keys are not trusted";
@@ -192,8 +192,8 @@
 {
     RT::Test->lsign_gnupg_key( $fpr1 );
     my %res = RT::Crypt::GnuPG::get_keys_info('rt-test at example.com');
-    ok $res{'info'}[0]{'TrustLevel'} > 0, 'trusted key';
-    is $res{'info'}[1]{'TrustLevel'}, 0, 'is not trusted key';
+    ok $res{'info'}[0]{'trust_level'} > 0, 'trusted key';
+    is $res{'info'}[1]{'trust_level'}, 0, 'is not trusted key';
 }
 
 diag "check that we see key selector even if only one key is trusted but there are more keys";
@@ -285,7 +285,7 @@
 
     my @mail = RT::Test->fetch_caught_mails;
     ok @mail, 'there are some emails';
-    check_text_emails( { encrypt => 1, Attachment => 1 }, @mail );
+    check_text_emails( { encrypt => 1, attachment => 1 }, @mail );
 }
 
 sub check_text_emails {
@@ -295,7 +295,7 @@
     ok scalar @mail, "got some mail";
     for my $mail (@mail) {
         for my $type ('email', 'attachment') {
-            next if $type eq 'attachment' && !$args{'Attachment'};
+            next if $type eq 'attachment' && !$args{'attachment'};
 
             my $content = $type eq 'email'
                         ? "Some content"

Modified: rt/branches/3.999-DANGEROUS/t/web/gnupg-select-keys-on-update.t
==============================================================================
--- rt/branches/3.999-DANGEROUS/t/web/gnupg-select-keys-on-update.t	(original)
+++ rt/branches/3.999-DANGEROUS/t/web/gnupg-select-keys-on-update.t	Sun Feb  3 00:25:21 2008
@@ -78,7 +78,7 @@
     RT::Test->import_gnupg_key('rt-recipient at example.com');
     RT::Test->trust_gnupg_key('rt-recipient at example.com');
     my %res = RT::Crypt::GnuPG::get_keys_info('rt-recipient at example.com');
-    is $res{'info'}[0]{'TrustTerse'}, 'ultimate', 'ultimately trusted key';
+    is $res{'info'}[0]{'trust_terse'}, 'ultimate', 'ultimately trusted key';
 }
 
 diag "check that things don't work if there is no key";
@@ -114,8 +114,8 @@
 {
     RT::Test->import_gnupg_key('rt-test at example.com', 'public');
     my %res = RT::Crypt::GnuPG::get_keys_info('rt-test at example.com');
-    is $res{'info'}[0]{'TrustLevel'}, 0, 'is not trusted key';
-    $fpr1 = $res{'info'}[0]{'Fingerprint'};
+    is $res{'info'}[0]{'trust_level'}, 0, 'is not trusted key';
+    $fpr1 = $res{'info'}[0]{'fingerprint'};
 }
 
 diag "check that things still doesn't work if key is not trusted";
@@ -162,8 +162,8 @@
 {
     RT::Test->import_gnupg_key('rt-test at example.com.2', 'public');
     my %res = RT::Crypt::GnuPG::get_keys_info('rt-test at example.com');
-    is $res{'info'}[1]{'TrustLevel'}, 0, 'is not trusted key';
-    $fpr2 = $res{'info'}[2]{'Fingerprint'};
+    is $res{'info'}[1]{'trust_level'}, 0, 'is not trusted key';
+    $fpr2 = $res{'info'}[2]{'fingerprint'};
 }
 
 diag "check that things still doesn't work if two keys are not trusted";
@@ -208,8 +208,8 @@
 {
     RT::Test->lsign_gnupg_key( $fpr1 );
     my %res = RT::Crypt::GnuPG::get_keys_info('rt-test at example.com');
-    ok $res{'info'}[0]{'TrustLevel'} > 0, 'trusted key';
-    is $res{'info'}[1]{'TrustLevel'}, 0, 'is not trusted key';
+    ok $res{'info'}[0]{'trust_level'} > 0, 'trusted key';
+    is $res{'info'}[1]{'trust_level'}, 0, 'is not trusted key';
 }
 
 diag "check that we see key selector even if only one key is trusted but there are more keys";
@@ -304,7 +304,7 @@
 
     my @mail = RT::Test->fetch_caught_mails;
     ok @mail, 'there are some emails';
-    check_text_emails( { encrypt => 1, Attachment => 1 }, @mail );
+    check_text_emails( { encrypt => 1, attachment => 1 }, @mail );
 }
 
 sub check_text_emails {
@@ -314,7 +314,7 @@
     ok scalar @mail, "got some mail";
     for my $mail (@mail) {
         for my $type ('email', 'attachment') {
-            next if $type eq 'attachment' && !$args{'Attachment'};
+            next if $type eq 'attachment' && !$args{'attachment'};
 
             my $content = $type eq 'email'
                         ? "Some content"


More information about the Rt-commit mailing list
--- rt/branches/3.999-DANGEROUS/lib/RT/Model/Transaction.pm	(original)
+++ rt/branches/3.999-DANGEROUS/lib/RT/Model/Transaction.pm	Sun Feb  3 00:25:21 2008
@@ -1187,7 +1187,7 @@
     my %args = (@_);
 
     # This method used to have an API that took a hash of a single
     # value "ARGSRef", which was a reference to a hash of arguments.
     # This was insane. The next few lines of code preserve that API
     # while giving us something saner.
 
@@ -1195,8 +1195,8 @@
 
     my $args;
 
-    if ( $args{'ARGSRef'} ) {
-        $args = $args{ARGSRef};
+    if ( $args{'args_ref'} ) {
+        $args = $args{args_ref};
     } else {
         $args = \%args;
     }
@@ -1187,7 +1187,7 @@
 
     # This method used to have an API that took a hash of a single
-    # value "ARGSRef", which was a reference to a hash of arguments.
+    # value "args_ref", which was a reference to a hash of arguments.
     # This was insane. The next few lines of code preserve that API
     # while giving us something saner.

Modified: rt/branches/3.999-DANGEROUS/lib/RT/Model/User.pm
==============================================================================